#
# spec file for package conftest
#
# Copyright (c) 2023 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


Name:           conftest
Version:        0.46.0
Release:        1.1
Summary:        Tool to write tests against structured configuration data
License:        Apache-2.0
URL:            https://github.com/open-policy-agent/conftest
Source0:        %{name}-%{version}.tar.gz
Source1:        vendor.tar.gz
BuildRequires:  golang-packaging
BuildRequires:  golang(API) >= 1.18

%description
Conftest helps you write tests against structured configuration data. Using Conftest you can write tests for your Kubernetes configuration, Tekton pipeline definitions, Terraform code, Serverless configs or any other config files.

%package bash-completion
Summary:        Bash Completion for %{name}
Group:          System/Shells
Requires:       %{name} = %{version}
Supplements:    (%{name} and bash-completion)
BuildArch:      noarch

%description bash-completion
Bash command line completion support for %{name}.

%package zsh-completion
Summary:        Zsh Completion for %{name}
Group:          System/Shells
Requires:       %{name} = %{version}
Supplements:    (%{name} and zsh)
BuildArch:      noarch

%description zsh-completion
Zsh command line completion support for %{name}.

%package fish-completion
Summary:        Fish Completion for %{name}
Group:          System/Shells
Requires:       %{name} = %{version}
Supplements:    (%{name} and fish)
BuildArch:      noarch

%description fish-completion
Fish command line completion support for %{name}.

%prep
%setup -qa1

%build
go build  -buildmode=pie -mod vendor -o bin/%{name}

%install
install -D -m 0755 ./bin/%{name} "%{buildroot}/%{_bindir}/%{name}"
mkdir -p %{buildroot}%{_datarootdir}/bash-completion/completions
%{buildroot}/%{_bindir}/%{name} completion bash > %{buildroot}%{_datarootdir}/bash-completion/completions/%{name}
mkdir -p %{buildroot}%{_datarootdir}/zsh_completion.d
%{buildroot}/%{_bindir}/%{name} completion zsh > %{buildroot}%{_datarootdir}/zsh_completion.d/_%{name}
mkdir -p %{buildroot}%{_datadir}/fish/vendor_completions.d
%{buildroot}/%{_bindir}/%{name} completion fish > %{buildroot}%{_datarootdir}/fish/vendor_completions.d/%{name}.fish

%files
%doc README.md
%license LICENSE
%{_bindir}/%{name}

%files bash-completion
%dir %{_datarootdir}/bash-completion/completions/
%{_datarootdir}/bash-completion/completions/%{name}

%files zsh-completion
%dir %{_datarootdir}/zsh_completion.d/
%{_datarootdir}/zsh_completion.d/_%{name}

%files fish-completion
%dir %{_datarootdir}/fish
%dir %{_datarootdir}/fish/vendor_completions.d
%{_datarootdir}/fish/vendor_completions.d/%{name}.fish

%changelog
* Thu Oct  5 2023 Johannes Kastl <kastl@b1-systems.de>
- change source URL to not generate a superfluous tarball
* Mon Oct  2 2023 kastl@b1-systems.de
- Update to version 0.46.0:
  * build(deps): bump github.com/open-policy-agent/opa from 0.56.0
    to 0.57.0 (#873)
  * chore: Update github.com/spdx/tools-golang to current version
    (#868)
  * fix: examples documentation (#869)
  * fix: cover built-in errors with a flag, suppress unless it's
    passed (#871)
  * build(deps): bump golang from 1.21.0-alpine to 1.21.1-alpine
    (#867)
  * fix: `--strict` flag when using `conftest verify` (#866)
  * chore: Update dependencies (#863)
* Tue Sep  5 2023 kastl@b1-systems.de
- Update to version 0.45.0:
  * chore: Replace ghodss/yaml with sigs.k8s.io/yaml (#858)
  * build(deps): bump github.com/open-policy-agent/opa from 0.55.0
    to 0.56.0 (#860)
  * cleanup: Use generics to simplify code for parse_config and
    related builtins (#857)
  * ci: Bump Go to 1.21.0 (#855)
  * build(deps): bump alpine from 3.18.2 to 3.18.3 (#851)
  * build(deps): bump golang from 1.20.7-alpine to 1.21.0-alpine
    (#850)
  * feat: added support for Azure DevOps output (#853)
  * build(deps): bump golang from 1.20.6-alpine to 1.20.7-alpine
    (#849)
  * build(deps): bump github.com/open-policy-agent/opa from 0.54.0
    to 0.55.0 (#848)
  * fix: Use Bool instead of BoolP for three flags (#847)
  * docs: Fix typo in options docs (#846)
  * build(deps): bump golang from 1.20.5-alpine to 1.20.6-alpine
    (#845)
  * ci: Check GoReleaser config before performing any release
    actions (#843)
* Sun Jul  9 2023 kastl@b1-systems.de
- (skipping non-existent release 0.44.0)
- Update to version 0.44.1:
  * ci: Migrate off of deprecated GoReleaser options (#842)
  * fix: examples/compose - a deny rule was incorrectly implemented
    (#841)
  * build(deps): bump github.com/open-policy-agent/opa from 0.53.1
    to 0.54.0 (#838)
  * fix: pretty print the built-in err structure (#839)
  * fix(tests): typo for hcl2 (#836)
  * build(deps): bump alpine from 3.18.0 to 3.18.2 (#835)
  * build(deps): bump golang from 1.20.4-alpine to 1.20.5-alpine
    (#834)
* Mon Jun 12 2023 kastl@b1-systems.de
- Update to version 0.43.1:
  * build(deps): bump github.com/open-policy-agent/opa from 0.53.0
    to 0.53.1 (#833)
  * build: Bump hashicorp/go-getter to v1.7.1 (#825)
* Mon Jun 12 2023 kastl@b1-systems.de
- Update to version 0.43.0:
  * build(deps): bump github.com/open-policy-agent/opa from 0.52.0
    to 0.53.0 (#830)
  * feat: Add textproto support (#828)
  * build(deps): bump alpine from 3.17.3 to 3.18.0 (#827)
  * docs: typo (#826)
* Mon May  8 2023 kastl@b1-systems.de
- Update to version 0.42.1:
  * build: Bump hashicorp/go-getter to v1.7.1 (#825)
  * build: Bump Go to 1.20.4 (#824)
  * build(deps): bump github.com/open-policy-agent/opa from 0.51.0
    to 0.52.0 (#821)
  * fix: plugins install command (#822)
  * feat: added quiet command to standard test output (#785)
  * docs: mention test-example in the readme (#819)
  * feat: Add exceptions to GitHub output (#818)
  * fix: Fixes a broken emoji in the NOTES section under
    Testing/Verifying Policies (#816)
  * build(deps): bump golang from 1.20.2-alpine to 1.20.3-alpine
    (#810)
  * fix: handle builtin errors returned from the rego evaluation
    (#812)
* Mon May  8 2023 kastl@b1-systems.de
- Update to version 0.42.1:
  * build: Bump hashicorp/go-getter to v1.7.1 (#825)
* Mon May  8 2023 kastl@b1-systems.de
- Update to version 0.42.0:
  * build: Bump Go to 1.20.4 (#824)
  * build(deps): bump github.com/open-policy-agent/opa from 0.51.0
    to 0.52.0 (#821)
  * fix: plugins install command (#822)
  * feat: added quiet command to standard test output (#785)
  * docs: mention test-example in the readme (#819)
  * feat: Add exceptions to GitHub output (#818)
  * fix: Fixes a broken emoji in the NOTES section under
    Testing/Verifying Policies (#816)
  * build(deps): bump golang from 1.20.2-alpine to 1.20.3-alpine
    (#810)
  * fix: handle builtin errors returned from the rego evaluation
    (#812)
  * build(deps): bump alpine from 3.17.2 to 3.17.3 (#809)
* Mon Apr  3 2023 kastl@b1-systems.de
- Update to version 0.41.0:
  * bump-up(docker): update parser to the latest to be able to
    parse all keywords (#805)
  * build(deps): bump github.com/open-policy-agent/opa from 0.50.2
    to 0.51.0 (#808)
  * fix: detect regardless of port and loopback (#806)
  * docs: fix verify docs/example code (#801)
* Fri Mar 24 2023 kastl@b1-systems.de
- Update to version 0.40.0:
  * fix: Use docker buildx for multi-platform builds (#804)
  * Use docker buildx for multi-platform builds
  * fix: no policies found (#794)
  * fix: Remove scheme from OCI URL before parsing it (#796)
  * feat: add strict compilation rules to policies being evaluated
    (#798)
  * build(deps): bump github.com/open-policy-agent/opa from 0.49.2
    to 0.50.2 (#797)
  * cleanup: Address issues from golang-lint (#799)
  * build(deps): bump golang from 1.20.1-alpine to 1.20.2-alpine
    (#792)
  * feat: support multi-arch docker build (linux/arm64 and
    linux/amd64) (#789)
  * feat: Add --config-file, -c; allow users to set the config file
    (#787)
  * feat: upgrade to ORAS Go v2 (#788)
  * build(deps): bump github.com/open-policy-agent/opa from 0.49.1
    to 0.49.2 (#784)
  * docs: bump github/action to v3 (#780)
  * build(deps): bump github.com/open-policy-agent/opa from 0.49.0
    to 0.49.1 (#779)
  * ci: Bump Go in CI to v1.20.1 (#778)
  * build(deps): bump golang from 1.19.5-alpine to 1.20.1-alpine
    (#777)
  * build(deps): bump alpine from 3.17.1 to 3.17.2 (#774)
* Fri Mar  3 2023 kastl@b1-systems.de
- Update to version 0.39.2:
  * build(deps): bump github.com/open-policy-agent/opa from 0.49.1
    to 0.49.2 (#784)
* Fri Mar  3 2023 kastl@b1-systems.de
- Update to version 0.39.1:
  * ci: Bump Go in CI to v1.20.1 (#778)
  * build(deps): bump alpine from 3.17.1 to 3.17.2 (#774)
  * build(deps): bump golang from 1.19.5-alpine to 1.20.1-alpine
    (#777)
  * build(deps): bump github.com/open-policy-agent/opa from 0.49.0
    to 0.49.1 (#779)
* Fri Mar  3 2023 kastl@b1-systems.de
- Update to version 0.39.0:
  * build(deps): bump github.com/open-policy-agent/opa from 0.48.0
    to 0.49.0 (#773)
  * build(deps): bump golang from 1.19.4-alpine to 1.19.5-alpine
    (#770)
  * build: support arm64 architecture (#768)
* Sat Jan 21 2023 dmueller@suse.com
- Update to version 0.38.0:
  * ci: Require commits to have conventional commit prefix (#766)
  * build(deps): bump github.com/open-policy-agent/opa from 0.47.4 to 0.48.0 (#767)
  * misc: Improve generated changelog (#765)
  * build(deps): bump github.com/open-policy-agent/opa from 0.47.3 to 0.47.4 (#764)
  * Added helper method to load combined config files for Rego unit tests (#762)
  * build(deps): bump github.com/open-policy-agent/opa from 0.47.2 to 0.47.3 (#760)
  * build(deps): bump golang from 1.18.5-alpine to 1.19.4-alpine (#761)
  * Bump OPA to 0.47.2 (#759)
  * Allow data-only bundles (#754)
  * build(deps): bump github.com/open-policy-agent/opa from 0.47.0 to 0.47.1 (#758)
  * build(deps): bump github.com/open-policy-agent/opa from 0.46.1 to 0.47.0 (#757)
  * build(deps): bump alpine from 3.16.3 to 3.17.0 (#756)
* Fri Dec 16 2022 Robert Munteanu <rombert@apache.org>
- Up-to-date syntax for supplements
* Fri Dec 16 2022 rombert@apache.org
- Update to version 0.36.0:
  * ci: [draft/test] fix runtime to 3.8 as it's default in focal (#755)
  * build(deps): bump alpine from 3.16.2 to 3.16.3 (#753)
  * fix: preserve metadata annotations on OCI registry push (#750)
  * Adding data flag to conftest push (#749)
  * build(deps): bump github.com/open-policy-agent/opa from 0.45.0 to 0.46.1 (#751)
  * Detect Quay.io OCI registry in downloader (#747)
  * workflow: update set-output usage (#745)
  * build(deps): bump github.com/open-policy-agent/opa from 0.44.0 to 0.45.0
  * Bump x/net and opa to patch CVEs (#743)
  * build(deps): bump github.com/open-policy-agent/opa from 0.43.0 to 0.44.0 (#739)
  * build(deps): bump alpine from 3.16.1 to 3.16.2 (#736)
  * Bump Go to v1.18.5 (#735)
  * build(deps): bump github.com/open-policy-agent/opa from 0.42.2 to 0.43.0 (#732)
  * docs: Add instructions for installing from source (#730)
  * docs: Fix 'polciies' -> 'policies' typo (#729)
  * Use pkg.go.dev for constants reference (#728)
  * Bump alpine from 3.16.0 to 3.16.1 (#727)
  * Add parse_config and parse_config_file builtins (#726)
  * Bump golang from 1.18.3-alpine to 1.18.4-alpine (#724)
  * Bump github.com/open-policy-agent/opa from 0.42.1 to 0.42.2 (#723)
  * Bump github.com/open-policy-agent/opa from 0.42.0 to 0.42.1 (#722)
  * Add OCI Push and Pull tests to CI (#718)
  * bug: Fix 404 error when using the push command (#721)
  * Bump github.com/open-policy-agent/opa from 0.41.0 to 0.42.0 (#720)
  * Update golang 1.18.3 (#719)
  * Bump golang from 1.18.2-alpine to 1.18.3-alpine (#714)
  * Bump github.com/open-policy-agent/opa from 0.40.0 to 0.41.0 (#713)
  * Bump github.com/hashicorp/go-getter to v1.6.1 (#712)
  * Bump golang from 1.18.1-alpine to 1.18.2-alpine (#710)
  * Bump alpine from 3.15.4 to 3.16.0 (#711)
  * Bump github.com/hashicorp/go-getter from 1.5.10 to 1.5.11 (#708)
  * Bump github.com/open-policy-agent/opa from 0.39.0 to 0.40.0 (#706)
  * Update oras-go to v1.1.1 (#702)
  * feat: add capabilities feature to conftest (#704)
  * Bump Go version in GHA workflows to 1.18.1 (#703)
  * Only emit valid JSON when using the parse command (#686)
  * Bump golang from 1.17.8-alpine to 1.18.1-alpine (#701)
  * Refactor JUnit output formatting (#699)
  * Update install.md - Fix install command (#692)
  * Bump OPA to 0.39.0
  * Make runner package public
  * Bump mkdocs to 1.3.0
  * Bump alpine to 3.15.4 for release image
  * Add parser for JSONC documents (#691)
  * Bump alpine from 3.15.0 to 3.15.1 (#688)
  * Bump github.com/open-policy-agent/opa from 0.38.0 to 0.38.1 (#685)
  * Bump golang from 1.17.7-alpine to 1.17.8-alpine (#683)
  * Bump github.com/open-policy-agent/opa from 0.37.2 to 0.38.0 (#681)
  * Install latest conftest version (#673)
  * Update Go version in pipelines to 1.17.7 (#679)
  * Bump golang from 1.17.6-alpine to 1.17.7-alpine (#678)
  * Add OPA version to --version output (#674)
  * Bump github.com/open-policy-agent/opa from 0.37.1 to 0.37.2 (#677)
  * Adding ppc64le support (#676)
  * Bump github.com/open-policy-agent/opa from 0.37.0 to 0.37.1 (#672)
  * Bump github.com/open-policy-agent/opa from 0.36.1 to 0.37.0 (#670)
  * docs: Update security link to point to new default branch (#668)
  * Bump Go to 1.17.6 in pull_request and release workflows (#665)
  * Bump github.com/open-policy-agent/opa from 0.36.0 to 0.36.1 (#664)
  * Bump golang from 1.17.5-alpine to 1.17.6-alpine (#663)
  * Prepare v0.30.0 release (#662)
  * Update containerd to v1.5.9 (#661)
  * Always use ORAS context when interacting with registry (#660)
  * Update dependencies (#659)
  * Add check flag to fmt command (#655)
  * Fix bug to allow for multiple plugins (#657)
  * Update Building and Testing documentation (#654)
  * Add new parser for .env files. (#653)
  * feat: add quiet flag to verify (#652)
  * Bump Dockerfile to alpine 1.17.5 (#651)
  * fix(exception): support empty string (#589)
  * Bump golang from 1.17.3-alpine to 1.17.4-alpine (#648)
  * feat: spdx parser (#636)
  * Add parser name to cyclonedx acceptance test otherwise json would be used (#646)
  * feat: cyclonedx parser (#637)
  * Bump alpine from 3.14.3 to 3.15.0 (#645)
  * add file path information in returned error message (#641)
  * Support for terragrunt default config files (#639)
  * chore: replace part of linter from golint to revive, fixed warning wh… (#635)
  * Update dependencies (#643)
  * Bump alpine from 3.14.2 to 3.14.3 (#638)
  * Bump github.com/open-policy-agent/opa from 0.34.0 to 0.34.2 (#634)
  * Bump golang from 1.17.2-alpine to 1.17.3-alpine (#633)
  * chore: point to the right channel (#630)
  * engine+reporter: enable `print()` output (#629)
  * Bump github.com/open-policy-agent/opa from 0.33.1 to 0.34.0 (#627)
  * DEVELOPMENT.md: bats -> bats-core (#628)
  * (chore) Bump Go to 1.17.2 (#625)
  * Bump mkdocs from 1.1 to 1.2.3 (#624)
  * upgrade Oras to oras-go v0.4.0 (#617)
  * Remove old examples (#620)
  * Bump nltk from 3.5 to 3.6.5 (#619)
  * Bump golang from 1.17.1-alpine to 1.17.2-alpine (#618)
  * Bump github.com/open-policy-agent/opa from 0.33.0 to 0.33.1 (#616)
  * Bump github.com/open-policy-agent/opa from 0.32.1 to 0.33.0 (#615)
* Tue Oct 19 2021 Robert Munteanu <rombert@apache.org>
- Initial pacakge
